using System;
using System.Collections.Generic;
using Autofac;
using FitConnect;
using FitConnect.Models;
using FitConnect.Security;
using MockContainer;
using NUnit.Framework;

namespace FluentApiTest;

public class FluentSenderTests {
    private Client _client = null!;
    private string clientId = "clientId";
    private string clientSecret = "clientSecret";
    private IContainer _container = null!;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        _container = Container.Create();
    }

    [SetUp]
    public void Setup() {
        var certificate = RsaEncryption.CreateSelfSignedCertificate();

        _client = new Client(
            FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development),
            "", "", certificate, certificate, container: _container);
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServices() {
        _client.Sender
            .Authenticate(clientId, clientSecret)
            .CreateSubmission(new Submission {
                Attachments = new List<Attachment>(), ServiceType = new ServiceType(),
                Destination = new Destination { LeikaKey = "09929292772", AreaId = "948488" }
            })
            .UploadAttachments()
            .SendSubmission(new Metadata(), new Data());
    }

    [Test]
    public void FluentSender_ShouldThrowArgumentException_MockingServices() {
        Assert.Throws<ArgumentException>(() => {
            _client.Sender
                .Authenticate(clientId, clientSecret)
                .CreateSubmission(new Submission {
                    Attachments = new List<Attachment>(), ServiceType = new ServiceType(),
                    Destination = new Destination { LeikaKey = "", AreaId = "948488" }
                })
                .UploadAttachments()
                .SendSubmission(new Metadata(), new Data());
        });
    }
}