using System.Security.Cryptography.X509Certificates;
using Autofac;
using FitConnect;
using FluentAssertions;
using NUnit.Framework;

namespace FluentApiTest;

public class FluentSubscriberReceiveTests {
    private Client _client = null!;
    private string clientId = "clientId";
    private string clientSecret = "clientSecret";
    private IContainer _container = null!;
    private X509Certificate2 _certificate;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        _container = MockContainer.Container.Create();
        _certificate = MockContainer.Container.Certificate;
    }

    [SetUp]
    public void SetUp() {
        _client = new Client(
            FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development), clientId,
            clientSecret, _certificate, _certificate,
            container: _container);
    }

    [Test]
    public void GetSubmission() {
        _client.Subscriber
            .Authenticate(clientId!, clientSecret!)
            .GetSubmission("submissionId")
            .GetAttachments()
            .ConfirmSubmission();

        var metadata = _client.Subscriber.Submission.Metadata;
        metadata.PublicServiceType.Name.Should().Be("Verwaltungsleistung");
    }
}
